@@ -4,7 +4,19 @@
 #' Recover clean, runnable code from a reprex captured in the wild and write it
 #' to user's clipboard. The code is also returned invisibly and optionally
 #' written to file. Three different functions address various forms of
-#' wild-caught reprex.
+#' wild-caught reprex:
+#'
+#' * `reprex_invert()` attempts to reverse the effect of [reprex()]. When
+#'   `venue = "r"`, this just calls `reprex_clean()`.
+#'
+#' * `reprex_clean()` removes commented output. This assumes that R code is
+#'   top-level, possibly interleaved with commented output, e.g., a displayed
+#'   reprex copied from GitHub or the output of `reprex(..., venue = "R")`.
+#'
+#' * `reprex_rescue()` removes lines of output and strips prompts from lines
+#'   holding R commands. This assumes that R code lines start with a prompt and
+#'   that printed output is top-level, e.g., what you'd if you've copied from
+#'   the R Console.
 #'
 #' @inheritParams reprex
 #' @param input Character. If has length one and lacks a terminating newline,
@@ -19,9 +31,7 @@
 #' @name un-reprex
 NULL
 
-#' @describeIn un-reprex Attempts to reverse the effect of [reprex()]. When
-#'   `venue = "r"`, this just calls `reprex_clean()`.
-#' @inheritParams reprex
+#' @rdname un-reprex
 #' @export
 #' @examples
 #' \dontrun{
@@ -62,10 +72,7 @@ reprex_invert <- function(input = NULL,
   reprex_undo(input, wd = wd, is_md = TRUE, comment = comment, outfile = outfile)
 }
 
-#' @describeIn un-reprex Assumes R code is top-level, possibly interleaved with
-#'   commented output, e.g., a displayed reprex copied from GitHub or the direct
-#'   output of `reprex(..., venue = "R")`. This function removes commented
-#'   output.
+#' @rdname un-reprex
 #' @export
 #' @examples
 #' \dontrun{
@@ -88,10 +95,7 @@ reprex_clean <- function(input = NULL,
   reprex_undo(input, wd = wd, is_md = FALSE, comment = comment, outfile = outfile)
 }
 
-#' @describeIn un-reprex Assumes R code lines start with a prompt and that
-#'   printed output is top-level, e.g., what you'd get from copy/paste from the
-#'   R Console. Removes lines of output and strips prompts from lines holding R
-#'   commands.
+#' @rdname un-reprex
 #' @export
 #' @examples
 #' \dontrun{
@@ -141,6 +145,7 @@ reprex_undo <- function(input = NULL,
   )
   r_file <- r_file_clean(undo_files$filebase)
   if (would_clobber(r_file)) {
+    reprex_warning("Cancelling to avoid overwriting a file.")
     return(invisible())
   }
 
