@@ -31,8 +31,7 @@ test_that("rmarkdown::render() context is trimmed from rlang backtrace", {
     "rlang::last_trace()"
   )
   ret <- reprex(input = input, advertise = FALSE)
-  expect_false(any(grepl("tryCatch", ret)))
-  expect_false(any(grepl("rmarkdown::render", ret)))
+  expect_no_match(ret, regexp = "tryCatch|rmarkdown::render")
 })
 
 test_that("rlang::last_error() and last_trace() work", {
@@ -49,32 +48,47 @@ test_that("rlang::last_error() and last_trace() work", {
   )
   ret <- reprex(input = input, advertise = FALSE)
   m <- match("rlang::last_error()", ret)
-  expect_false(grepl("Error", ret[m + 1]))
+  expect_no_match(ret[m + 1], "Error")
   m <- match("rlang::last_trace()", ret)
-  expect_false(grepl("Error", ret[m + 1]))
+  expect_no_match(ret[m + 1], "Error")
 })
 
 test_that("reprex() works even if user uses fancy quotes", {
   skip_on_cran()
   withr::local_options(list(useFancyQuotes = TRUE))
   # use non-default venue to force some quoted yaml to be written
-  expect_error_free(reprex(1, venue = "R"))
+  expect_no_error(reprex(1, venue = "R"))
 })
 
 test_that("reprex() errors for an R crash, by default", {
-  # TODO: consider switching to expect_snapshot() after switch to 3e
-  code <- 'utils::getFromNamespace("crash", "callr")()\n'
-  expect_error(reprex(input = code), "crash")
+  skip_on_cran()
+  expect_snapshot(error = TRUE, {
+    code <- 'rlang::node_car(0)\n'
+    reprex(input = code)
+  })
 })
 
 test_that("reprex() copes with an R crash, when `std_out_err = TRUE`", {
-  # TODO: consider switching to expect_snapshot() after switch to 3e
-  code <- 'utils::getFromNamespace("crash", "callr")()\n'
-  expect_error_free(
+  skip_on_cran()
+  code <- 'rlang::node_car(0)\n'
+  expect_no_error(
     out <- reprex(input = code, std_out_err = TRUE)
   )
+
   skip_on_os("windows")
-  expect_match(out, "crash", all = FALSE)
-  expect_match(out, "segfault", all = FALSE)
-  expect_match(out, "Traceback", all = FALSE)
+
+  scrubber <- function(x) {
+    # I don't want to snapshot the actual traceback
+    out <- x[seq_len(min(grep("Traceback", x)))]
+    # on macOS and windows, cause is 'invalid permissions'
+    # on ubuntu, cause is 'memory not mapped'
+    out <- sub(
+      "address 0x[0-9a-fA-F]+, cause '.*'",
+      "address ADDRESS, cause 'CAUSE'",
+      out
+    )
+    trimws(out)
+  }
+
+  expect_snapshot(out, transform = scrubber)
 })
